package jxscanner

import (
	"janex/admin-dashboard-backend/modules/database"
	"janex/admin-dashboard-backend/modules/structs"
	"janex/admin-dashboard-backend/modules/utils"
	"janex/admin-dashboard-backend/routers/router/api/v1/user"
	"time"

	"github.com/gofiber/fiber/v2"
	"github.com/rs/zerolog/log"
	"github.com/savsgio/gotils/uuid"
)

func AddScanner(c *fiber.Ctx) error {
	var body structs.ScannerRequest

	if err := c.BodyParser(&body); err != nil {
		log.Error().Msg("Failed to parse body, err: " + err.Error())
		return c.Status(fiber.StatusBadRequest).JSON(err)
	}

	if err := utils.ValidateStruct(body); err != nil {
		log.Error().Msgf("Failed to validate body, err: %s", err)
		return c.SendStatus(fiber.StatusBadRequest)
	}

	id := uuid.V4()
	session, err := user.GenerateSession()

	if err != nil {
		log.Error().Msgf("Failed to create session for scanner: %v", err)
		return c.SendStatus(fiber.StatusInternalServerError)
	}

	database.DB.Create(&structs.Scanner{
		Id:           id,
		Session:      session,
		Name:         body.ScannerName,
		UserAgent:    string(c.Context().UserAgent()),
		RegisteredAt: time.Now(),
	})

	return c.JSON(structs.ScannerResponse{Id: id, Session: session})
}
